%global basepkg shellinabox

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _socketfile_postfix common.socket
%else
  %global _servicefile_postfix xinetd
%endif

Summary: Easy to use configuration for Shell In A Box
Name: %{basepkg}-config
Version: 0.3
Release: 1%{?dist}
License: GPL-2.0-only
Group: System Environment/Daemons
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{basepkg}-ssh.sh
Source1: %{basepkg}-ssh.conf
%if %{_has_systemd}
Source2: %{basepkg}-sshd@.%{_servicefile_postfix}
Source3: %{basepkg}-sshd.%{_socketfile_postfix}
%else
Source2: %{basepkg}-sshd.%{_servicefile_postfix}
%endif
Source4: %{basepkg}d.sample
Requires: openssh-server, %{basepkg}
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires: xinetd
Requires(post): /sbin/service
Requires(postun): /sbin/service
%endif
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
This package provides an easy to use configuration for Shell In A Box.

%prep
%{__install} -d %{_builddir}/%{name}-%{version}
%{__install} -m 0644 -p %{SOURCE4} %{_builddir}/%{name}-%{version}/

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_sbindir}
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/pam.d
%{__install} -d %{buildroot}%{_sysconfdir}/ssh

%{__install} -m 0755 -p %{SOURCE0} %{buildroot}%{_bindir}/%{basepkg}-ssh
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_unitdir}/%{basepkg}-sshd@.service
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_unitdir}/%{basepkg}-sshd.socket
%else
%{__install} -d %{buildroot}%{_sysconfdir}/xinetd.d
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/xinetd.d/%{basepkg}-sshd
%endif

%{__ln_s} -f sshd %{buildroot}%{_sbindir}/%{basepkg}-sshd
%{__ln_s} -f sshd %{buildroot}%{_sysconfdir}/pam.d/%{basepkg}-sshd
%{__ln_s} -f sshd_config %{buildroot}%{_sysconfdir}/ssh/%{basepkg}-sshd_config

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{basepkg}-sshd.socket
%else
/sbin/service xinetd reload > /dev/null 2>&1 || :
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{basepkg}-sshd.socket
%endif

%postun
%if ! %{_has_systemd}
if [ $1 -eq 0 ]; then
  /sbin/service xinetd reload > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{version}/%{basepkg}d.sample
%attr(0755,root,root) %{_bindir}/%{basepkg}-ssh
%config(noreplace) %{_sysconfdir}/sysconfig/%{basepkg}-ssh.conf
%if %{_has_systemd}
%{_unitdir}/%{basepkg}-sshd@.service
%{_unitdir}/%{basepkg}-sshd.socket
%else
%config(noreplace) %{_sysconfdir}/xinetd.d/%{basepkg}-sshd
%endif
%{_sbindir}/%{basepkg}-sshd
%config(noreplace) %{_sysconfdir}/pam.d/%{basepkg}-sshd
%config(noreplace) %{_sysconfdir}/ssh/%{basepkg}-sshd_config

%changelog
* Thu Jun 15 2023 Simon Matter <simon.matter@invoca.ch> 0.3-1
- add support for systemd

* Tue Sep 02 2014 Simon Matter <simon.matter@invoca.ch> 0.2-1
- update sample config for shellinaboxd
- change port of private sshd instance to 4201

* Mon Sep 01 2014 Simon Matter <simon.matter@invoca.ch> 0.1-1
- initial package
