#!/bin/bash -i

LOGIN_TIMEOUT=20
ALLOWED_CHARS='[^a-zA-Z0-9.]'
ALLOWED_USERS=""
SSH_HOST="localhost"
SSH_PORT=4201

if [[ -f /etc/sysconfig/shellinabox-ssh.conf ]]; then
  . /etc/sysconfig/shellinabox-ssh.conf
fi

# do not allow read to be interrupted by Ctrl+C
trap "" SIGHUP SIGINT SIGABRT SIGTERM

read -rp "${SSH_HOST} login: " -t $LOGIN_TIMEOUT SSH_USER
RETVAL=$?

# slow down login rate
read -t 1 < /dev/stderr

# reset signal handlers
trap - SIGHUP SIGINT SIGABRT SIGTERM

if (( RETVAL )); then
  echo
  echo "error: login cancelled or timed out"
  exit 1
elif ! [[ "$SSH_USER" ]]; then
  echo "error: empty user name"
  exit 1
elif [[ "$SSH_USER" != "${SSH_USER/$ALLOWED_CHARS}" ]]; then
  echo "error: invalid user name"
  exit 1
elif ! [[ "$ALLOWED_USERS" ]]; then
  # accept this user if there is no allowed user list
  ALLOWED_USERS="$SSH_USER"
fi

for ALLOWED_USER in $ALLOWED_USERS; do
  if [[ "$SSH_USER" == "$ALLOWED_USER" ]]; then
    exec ssh -qxp $SSH_PORT -l "${SSH_USER}" "${SSH_HOST}"
    # this should never be reached
    exit 1
  fi
done

echo "error: invalid user login"
exit 1
